class GenomeDownloadError(Exception):

    """Error while downloading genome."""

    pass  # noqa
